@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Lesser General
  * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1335, USA.
  *
  * Authors:
  *	Caleb Moore <c.moore@student.unsw.edu.au>
@@ -69,10 +69,12 @@ lsm_svg_filter_surface_new_with_content (const char *name, cairo_surface_t *surf
 	    cairo_image_surface_get_format (surface) != CAIRO_FORMAT_ARGB32) {
 		surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, 0, 0);
 		subregion = &null_subregion;
-	} else if (subregion == NULL)
+	} else if (subregion == NULL) {
 		subregion = &null_subregion;
-
-	cairo_surface_reference (surface);
+		cairo_surface_reference (surface);
+	} else {
+		cairo_surface_reference (surface);
+	}
 
 	filter_surface = g_new (LsmSvgFilterSurface, 1);
 	filter_surface->name = g_strdup (name);
@@ -505,6 +507,7 @@ lsm_svg_filter_surface_flood (LsmSvgFilterSurface *surface,
 	cairo_clip (cairo);
 	cairo_set_source_rgba (cairo, red, green, blue, opacity);
 	cairo_paint (cairo);
+	cairo_destroy (cairo);
 }
 
 void
